#include "TF2.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TMath.h"

void FormatAxis(TAxis * axis){
  axis->SetLabelFont(42);
  axis->SetLabelSize(0.05);
  axis->SetLabelOffset(0.015);
  axis->SetNdivisions(510);
  axis->SetTitleFont(42);
  axis->SetTitleColor(1);
  axis->SetTitleSize(0.065);
  axis->SetTitleOffset(1.0);
  axis->CenterTitle();
}


void myFormatAxis(TH2 * hist ) 
{ 
  hist->Draw();
  FormatAxis( hist->GetXaxis() );
  FormatAxis( hist->GetYaxis() );
  FormatAxis( hist->GetZaxis() );
  hist->GetXaxis()->SetNdivisions(505); 
  hist->GetYaxis()->SetNdivisions(505); 
  hist->GetXaxis()->SetTitle("m_{12}^{2} [GeV^{2}/c^{4}]");
  hist->GetYaxis()->SetTitle("m_{23}^{2} [GeV^{2}/c^{4}]");
}
 

// needed in determination of Dalitz boundary
Double_t E2(Double_t x, Double_t m1, Double_t m2)
{         
  Double_t e2 = (x-m1*m1+m2*m2)/(2*sqrt(x));
  return e2;
}         
          
Double_t E3(Double_t x, Double_t M, Double_t m3)
{         
  Double_t e3 = (M*M-x-m3*m3)/(2*sqrt(x));
  return e3;
} 

Double_t m23Max(Double_t *x, Double_t *par) //par = { M, m1, m2, m3}
{         
  Double_t term1 = ( E2(x[0],par[1],par[2]) + E3(x[0],par[0],par[3]) );
  term1 = term1*term1;
          
  Double_t E2sqr= E2(x[0],par[1],par[2])*E2(x[0],par[1],par[2]);
  Double_t E3sqr= E3(x[0],par[0],par[3])*E3(x[0],par[0],par[3]);
          
  Double_t term2 = sqrt(E2sqr-par[2]*par[2])-sqrt( E3sqr - par[3]*par[3] );
  term2 = term2*term2;
  Double_t xx = term1 - term2;
  return xx;
}

Double_t m23Min(Double_t *x, Double_t *par) //par = { M, m1, m2, m3}
{         
  Double_t term1 = ( E2(x[0],par[1],par[2]) + E3(x[0],par[0],par[3]) );
  term1 = term1*term1;
          
  Double_t E2sqr= E2(x[0],par[1],par[2])*E2(x[0],par[1],par[2]);
  Double_t E3sqr= E3(x[0],par[0],par[3])*E3(x[0],par[0],par[3]);
          
  Double_t term2 = sqrt(E2sqr-par[2]*par[2])+sqrt( E3sqr - par[3]*par[3] );
  term2 = term2*term2;
  Double_t xx = term1 - term2;
  return xx;                                                                                               
}         
 

void DalitzPlotBoundary()  
{
  gStyle->SetPadTopMargin(0.07);
  gStyle->SetPadLeftMargin(0.16);
  gStyle->SetPadBottomMargin(0.16);
  gStyle->SetPadRightMargin(0.15);

  // M -> D1 D2 D3 (D0:1.86483, Ks:0.497611, K+:0.493677, pi+:0.139570, pi0:0.134977)
  double MassM = 1.86483; //D0  
  double mDaug1(0), mDaug2(0), mDaug3(0);   
  //---- For DzToKPiPi0
  //char str[100]="D^{0}#rightarrowK^{-}#pi^{+}#pi^{0}";
  //mDaug1 = 0.493677; mDaug2 = 0.139570; mDaug3 = 0.134977; 
  //---- For DzToKsPiPi
  //char str[100]="D^{0}#rightarrowK_{S}^{0}#pi^{+}#pi^{-}";
  //mDaug1 = 0.497611; mDaug2 = 0.139570; mDaug3 = 0.139570; 
  //---- For DzToKsKK
  //char str[100]="D^{0}#rightarrowK_{S}^{0}K^{+}K^{-}";
  //mDaug1 = 0.497611; mDaug2 = 0.493677; mDaug3 = 0.493677; 
  //---- For LcToPKPi
  char str[100]="#Lambda_{c}^{+}#rightarrowpK^{-}#pi^{+}";
  MassM = 2.28646; mDaug1 = 0.938; mDaug2 = 0.493677; mDaug3 = 0.139570; 

  if( MassM< (mDaug1+mDaug2+mDaug3) )  {
    cout<<"Error: The mass of mother is smaller than the sum of FSPs."<<endl;
    return; 
  }
  cout<<"Mass: "<< MassM <<" -> "<< mDaug1 <<" "<< mDaug2 <<" "<< mDaug3 <<endl; 

  double scale = 0.05; 
  if( MassM>2 ) scale = 0.01; 
  double xFitMin = (mDaug1+mDaug2)*(mDaug1+mDaug2)*(1-2*scale); 
  double xFitMax = (MassM-mDaug3)*(MassM-mDaug3)*(1+scale); 
  double yFitMin = (mDaug2+mDaug3)*(mDaug2+mDaug3)*(1-2*scale);
  double yFitMax = (MassM-mDaug1)*(MassM-mDaug1)*(1+scale);
  TH2D* dlzMSR = new TH2D("dlzMSR", "", 500, xFitMin, xFitMax, 500, yFitMin, yFitMax );
  
  //Dalitz Plane Boundary    
  double mDecay[4] = {MassM, mDaug1, mDaug2, mDaug3};
  TF1 *tf1 = new TF1("tf1", m23Max, (mDaug1+mDaug2)*(mDaug1+mDaug2), (MassM-mDaug3)*(MassM-mDaug3), 4);//x axis m12
  tf1->SetParameters(MassM,mDaug1,mDaug2,mDaug3);
  tf1->SetNpx(300);          
  TF1 *tf2 = new TF1("tf2", m23Min, (mDaug1+mDaug2)*(mDaug1+mDaug2), (MassM-mDaug3)*(MassM-mDaug3), 4);//x axis m12
  tf2->SetParameters(MassM,mDaug1,mDaug2,mDaug3);
  tf2->SetNpx(300);         
  std::vector<double> v_x,v_y;
  v_x.clear(); v_y.clear(); 
  TGraph* g1 = new TGraph(tf1,"");
  TGraph* g2 = new TGraph(tf2,"");
  int x1N = g1->GetN();       
  int x2N = g2->GetN();       
  double *g1x, *g1y, *g2x, *g2y;
  double lx = (mDaug1+mDaug2)*(mDaug1+mDaug2)+0.00001; 
  double rx = (MassM-mDaug3)*(MassM-mDaug3)-0.00001; 
  double ly = m23Max(&lx, mDecay);
  double ry = m23Min(&rx, mDecay);
  g1x = g1->GetX(); g1y = g1->GetY(); 
  g2x = g2->GetX(); g2y = g2->GetY();
  for(int i=0; i<x1N; i++)    
    { 
      v_x.push_back(*(g1x+i));
      v_y.push_back(*(g1y+i));
    } 
  v_x.push_back(rx);  v_y.push_back(ry);
  for(int i=x2N-1; i>=0; i--) 
    { 
      v_x.push_back(*(g2x+i));
      v_y.push_back(*(g2y+i));
    } 
  v_x.push_back(lx);  
  v_y.push_back(ly);
  v_x.push_back(v_x.at(0));  
  v_y.push_back(v_y.at(0));
  TGraph* DlzBoundary = new TGraph(v_x.size(),&v_x[0],&v_y[0]);
  DlzBoundary->SetLineColor(2);
  DlzBoundary->SetLineWidth(3);
  DlzBoundary->SetName("DlzBoundary");
  //Dalitz Plane Boundary
  //DlzBoundary->Draw("C");

  TCanvas *cav1 = new TCanvas("cav1", "Dalitz plot in S.R.", 600, 480 );
  cav1->cd();
  cav1->SetGrid();
  myFormatAxis( dlzMSR  );
  dlzMSR->Draw(); 
  
  DlzBoundary->SetLineColor(4);
  DlzBoundary->Draw("C");

  cout<< str <<endl;
  TLatex * decStr = new TLatex( 0.8, 0.88, str );
  decStr->SetNDC();
  decStr->SetTextFont(102);
  decStr->SetTextSize(0.07);
  decStr->SetTextAlign(33);
  decStr->Draw();

  cav1->Print("./DalitzPlotRegion.eps");
  std::cout<<"---- Finished ----"<<std::endl; 
}
