#include "plotstyle/bes3plotstyle.C"

void myFormatAxis( RooPlot *hist, int num)
{
  if( num==1 ) {
    hist->GetYaxis()->SetTitleOffset(1.0); 
    hist->GetXaxis()->SetTitleOffset(1.0);
    hist->GetXaxis()->CenterTitle();
    hist->GetYaxis()->CenterTitle();
  //hist->GetXaxis()->SetNdivisions(505);
    hist->GetXaxis()->SetLabelSize(0.05);  
    hist->GetYaxis()->SetLabelSize(0.05);
  } else if( num==2 ) {
    hist->SetMarkerSize(0.05);               
    hist->GetXaxis()->SetLabelSize(0.15);    
    hist->GetXaxis()->SetTitleOffset(2.0);  
    hist->GetYaxis()->SetLabelSize(0.15); 
    hist->GetYaxis()->SetTitle("Pull");
    hist->GetXaxis()->SetTitle(""); 
    hist->GetYaxis()->CenterTitle();
    hist->GetYaxis()->SetTitleFont(42);
    hist->GetYaxis()->SetTitleColor(1);
    hist->GetYaxis()->SetTitleSize(0.2);
    hist->GetYaxis()->SetTitleOffset(0.2);   
    hist->GetYaxis()->SetNdivisions(504);
  }
}
 

void fitM_LcSCS_blind()  
{
  SetStyle();
  SetPrelimStyle();
  TGaxis::SetMaxDigits(3);
//gStyle->SetPadRightMargin(0.08);
  gStyle->SetPadTopMargin(0.08);
  gStyle->SetOptStat(0);
  gStyle->SetFillStyle(0);  

  using namespace RooFit;
  RooMsgService::instance().deleteStream(0) ;
  RooMsgService::instance().deleteStream(1) ;
  RooMsgService::instance().Print() ;
  cout << endl ;

  TChain *tree= new TChain("tree");
  tree->Add("DumpROOT/LcSCS_data.root/treeAll");
  //double Nmax = tree->GetEntries(); 
  //cout<<"Total Input events No. = "<< Nmax <<endl;
  
  int nbin(90);
  double mMean(2.28646), mFitMin(2.245), mFitMax(2.335);
  RooRealVar massLc("massLc","M(Lc)", mFitMin, mFitMax, "GeV/c^{2}");

  //define sidebands 
  massLc.setRange("FR", mFitMin, mFitMax ); 
  massLc.setRange("LSB", mFitMin, 2.270 ); 
  massLc.setRange("RSB", 2.305 , mFitMax ); 

  // DATA SAMPLE
  RooDataSet *Data = new RooDataSet("Data","data sample", RooArgSet(massLc), Import(*tree), Cut("massLc<2.270||massLc>2.305") );
  double Nmax = Data->numEntries(); 
  cout<<"Total Input events No. = "<<std::setprecision(8) << Nmax <<endl;
   
  RooRealVar mmu1("mmu1", "mass D0", mMean, mFitMin, mFitMax );
  RooRealVar sigma1("sigma1", "sigma1", 2.56943e-03, 0.0001, 0.01 );
  RooGaussian gauss1("gauss1","gauss1 PDF", massLc, mmu1, sigma1 );
   
  RooRealVar xsigma2("xsigma2", "xsigma2", 1.21868e+00, 0.70 , 10.00 );
  RooFormulaVar sigma2("sigma2", "sigma1*xsigma2", RooArgList(sigma1, xsigma2));
//RooGaussian gauss2("gauss2","gauss2 PDF", massLc, mmu1, sigma2 );
  RooRealVar dsig2("dsig2", "dsig2", 1.62506e-02, -0.69 , 0.69 );
  RooFormulaVar sig2L("sig2L", "", "sigma2*(1.0+dsig2)", RooArgList(sigma2, dsig2));
  RooFormulaVar sig2R("sig2R", "", "sigma2*(1.0-dsig2)", RooArgList(sigma2, dsig2));
  RooBifurGauss gauss2("gauss2","gauss2 PDF", massLc, mmu1, sig2L, sig2R );
   
  RooRealVar xsigma3("xsigma3", "xsigma3", 1.85513e+00, 1.00 , 10.00 );
  RooFormulaVar sigma3("sigma3", "sigma2*xsigma3", RooArgList(sigma2, xsigma3));
  RooGaussian gauss3("gauss3","gauss3 PDF", massLc, mmu1, sigma3 );
   
  RooRealVar sig1frac("sig1frac","fraction of main G", 5.76740e-01, 0.1, 0.9 );
  RooRealVar sig2frac("sig2frac","fraction of DG", 9.01569e-01, 0.5, 1.0 );
  RooAddPdf sigpdf12("sigpdf12", "two-gaussian", RooArgList(gauss1,gauss2),RooArgList(sig1frac ) );
  RooAddPdf sigpdf("sigpdf", "three-gaussian", RooArgList(sigpdf12,gauss3),RooArgList(sig2frac) );

    dsig2.setVal(4.98205e-02); dsig2.setConstant(kTRUE);
    mmu1.setVal(2.28643e+00); mmu1.setConstant(kTRUE);
    sig1frac.setVal(5.95094e-01); sig1frac.setConstant(kTRUE);
    sig2frac.setVal(9.44844e-01); sig2frac.setConstant(kTRUE);
    sigma1.setVal(1.79880e-03); sigma1.setConstant(kTRUE);
    xsigma2.setVal(2.08738e+00); xsigma2.setConstant(kTRUE);
    xsigma3.setVal(4.10567e+00); xsigma3.setConstant(kTRUE);

  RooRealVar bkga1("bkga1", "bkga1",  2.95311e-02, -1.10, 1.10 ); 
  RooChebychev bkgpdf( "bkgpdf", "poly PDF", massLc, RooArgList( bkga1 ) );
  bkga1.setVal(2.91300e-02); //bkga1.setConstant(kTRUE); 

  // combined PDF
  RooRealVar Nsig("Nsig","number of signal", 0 );
  RooRealVar Nbkg("Nbkg","number of background", 1.0*Nmax, 0.85*Nmax, 3.15*Nmax );
  RooAddPdf sumpdf("sumpdf", "sum of pdf", RooArgList( sigpdf, bkgpdf ), RooArgList(Nsig, Nbkg));
   
  //fit data with unbinned maximum likelihood method
  RooFitResult *fiter = sumpdf.fitTo(*Data, Range("LSB,RSB"), Strategy(2), Hesse(kTRUE), Save(kTRUE), Minos(kFALSE)) ;
  fiter->Print();            

  double npar = fiter->floatParsFinal().getSize();
  double Vlikelihood = fiter->minNll();
  cout<<"N(free par)= "<< npar <<endl;
  printf("minimized -log(L) = %.2f\n", Vlikelihood );
   
  // ------------------------------------------------------------- //
  // PLOTS (ALL FIT REGION)
  // Observable
  RooPlot* varFrameFit = massLc.frame(Title("Signal"),Bins(nbin));
  Data->plotOn(varFrameFit, DataError(RooAbsData::SumW2), MarkerSize(1.0), RooFit::Name("Mproj"));
  sumpdf.plotOn(varFrameFit, LineWidth(2), LineColor(2), Range("LSB,RSB"), RooFit::NormRange("LSB,RSB"));
  varFrameFit->SetFillColor(0);
  varFrameFit->SetFillStyle(0);
  // ------------------------------------------------------------- //
  cout << "chi^2("<< npar <<") = " << varFrameFit->chiSquare( npar ) << endl ;
  //-------------------------------------------------------------- //
  varFrameFit->Print("V"); 
   auto dataHist  = (RooHist*) varFrameFit->getHist("Mproj"); 
   auto curve1 = (RooCurve*) varFrameFit->getObject(1);  // 1 is index in the list of RooPlot items (see printout from massplot->Print("V")  
   auto curve2 = (RooCurve*) varFrameFit->getObject(2);
   auto hresid1 =  dataHist->makePullHist(*curve1,true);
   auto hresid2 =  dataHist->makePullHist(*curve2,true);
   hresid1->SetFillColor(15); hresid1->SetLineColor(0);
   hresid2->SetFillColor(15); hresid2->SetLineColor(0);
   RooPlot* framePull = massLc.frame( Title("Pull") ) ;
   framePull->addPlotable(hresid1,"B"); 
   framePull->addPlotable(hresid2,"B"); 
   framePull->SetTitle("");
   framePull->GetYaxis()->SetRangeUser( -4.0, 4.0 );

  sumpdf.plotOn(varFrameFit, Components(bkgpdf), LineStyle(2), LineColor(4), Range("LSB,RSB"), RooFit::NormRange("LSB,RSB"), RooFit::Name("Mfitbkg"));
  sumpdf.plotOn(varFrameFit, LineWidth(2), LineColor(2), Range("LSB,RSB"), RooFit::NormRange("LSB,RSB"), RooFit::Name("Mfitall"));

  TCanvas* cav1 = new TCanvas("cav1","mc M(D) fit", 600, 500 );
  TPad *pad1 = new TPad("pad1","pad1",0.01,0.20,0.99,0.99);
  TPad *pad2 = new TPad("pad2","pad2",0.01,0.01,0.99,0.20);
  pad1->Draw();
  pad2->Draw();
 
  pad1->cd();
  pad1->SetLeftMargin(0.15);
  myFormatAxis( varFrameFit, 1 );
  varFrameFit->GetYaxis()->SetTitle("Events / (1 MeV/#it{c}^{2})");
  varFrameFit->GetXaxis()->SetTitle("M(#Lambda_{c}^{+}) (GeV/#it{c}^{2})");
  varFrameFit->GetYaxis()->SetRangeUser(0, varFrameFit->GetMaximum()*1.5);
  varFrameFit->Draw();
 
  double legxmin=0.60, legxmax=0.90; 
  TLegend *leg = new TLegend( legxmin, 0.68, legxmax, 0.90 );          
  leg->AddEntry( varFrameFit->findObject("Mproj"), "Data", "EP");
  leg->AddEntry( varFrameFit->findObject("Mfitall"), "Total fit", "l");
//leg->AddEntry( varFrameFit->findObject("Mfitsig"), "Signal", "l");
  leg->AddEntry( varFrameFit->findObject("Mfitbkg"), "Background", "l");
  leg->SetFillStyle(0);
  leg->SetTextFont(42);
  leg->Draw();
 
  pad2->cd();
  pad2->SetLeftMargin(0.15);
  myFormatAxis( framePull, 2 );
  framePull->Draw();
  PullLine( mFitMin, mFitMax );

  cav1->cd();
//cav1->Print("./eps/Massfit_LcSCS_Data_blind.eps");
}
