#include "plotstyle/bes3plotstyle.C"

void myFormatAxis( RooPlot *hist, int num)
{
  if( num==1 ) {
    hist->GetYaxis()->SetTitleOffset(1.0); 
    hist->GetXaxis()->SetTitleOffset(1.0);
    hist->GetXaxis()->CenterTitle();
    hist->GetYaxis()->CenterTitle();
  //hist->GetXaxis()->SetNdivisions(505);
    hist->GetXaxis()->SetLabelSize(0.05);  
    hist->GetYaxis()->SetLabelSize(0.05);
  } else if( num==2 ) {
    hist->SetMarkerSize(0.05);               
    hist->GetXaxis()->SetLabelSize(0.15);    
    hist->GetXaxis()->SetTitleOffset(2.0);  
    hist->GetYaxis()->SetLabelSize(0.15); 
    hist->GetYaxis()->SetTitle("Pull");
    hist->GetXaxis()->SetTitle(""); 
    hist->GetYaxis()->CenterTitle();
    hist->GetYaxis()->SetTitleFont(42);
    hist->GetYaxis()->SetTitleColor(1);
    hist->GetYaxis()->SetTitleSize(0.2);
    hist->GetYaxis()->SetTitleOffset(0.2);   
    hist->GetYaxis()->SetNdivisions(504);
  }
}
 

void fitM_feedbkg_Ref()  
{
  SetStyle();
  SetPrelimStyle();
//TGaxis::SetMaxDigits(3);
//gStyle->SetPadRightMargin(0.08);
//gStyle->SetPadTopMargin(0.08);
  gStyle->SetOptStat(0);
  gStyle->SetFillStyle(0);  

  using namespace RooFit;
  RooMsgService::instance().deleteStream(0) ;
  RooMsgService::instance().deleteStream(1) ;
  RooMsgService::instance().Print() ;
  cout << endl ;

  
  TChain *tree= new TChain("tree"); 
  TString stCut = "sigFlag!=1";
  tree->Add("DumpROOT/LcRef_genericMC.root/treeAll");
  stCut = "sigFlag==5";

  int nbin(90);
  double mMean(2.28646), mFitMin(2.245), mFitMax(2.335);
  nbin=100; mFitMin=2.15; mFitMax=2.45; 
   
  // DATA SAMPLE
  RooRealVar massLc("massLc","M(#Lambda_{c}^{+})", mFitMin, mFitMax, "GeV/c^{2}");
  RooRealVar sigFlag("sigFlag","MC flag", -1, 10 );
  RooDataSet *Data = new RooDataSet("Data","data sample", RooArgSet(massLc, sigFlag), Import(*tree), Cut("sigFlag==3") );
  double Nfit = Data->numEntries(); 
  cout<<"to be fitted, Nsig = "<< std::setprecision(8)<< Nfit <<endl; 

  //method 1 (taking toooo long time, abandoned.)
//RooKeysPdf sumpdf("sumpdf", "", massLc, *Data, RooKeysPdf::MirrorBoth, 1 );
  //method 2:
  massLc.setBins( nbin ) ;
  RooDataHist* hist2 = new RooDataHist("hist2", "", RooArgSet(massLc), *Data);
  RooHistPdf sumpdf("sumpdf","sumpdf", massLc, *hist2, 2) ; 

  //fit data with unbinned maximum likelihood method
  sumpdf.fitTo(*Data, Strategy(2), Hesse(kFALSE), Save(kTRUE), Minos(kFALSE) ) ;
  RooFitResult *fiter = sumpdf.fitTo(*Data, Strategy(2), Hesse(kTRUE), Save(kTRUE), Minos(kFALSE) ) ;
//double npar = fiter->floatParsFinal().getSize();
//double Vlikelihood = fiter->minNll();
//cout<<"N(free par)= "<< npar <<endl;
//printf("minimized -log(L) = %.2f\n", Vlikelihood );
   
  // ------------------------------------------------------------- //
  // PLOTS (ALL FIT REGION)
  // Observable
  RooPlot* varFrameFit = massLc.frame(Title("Signal"),Bins(nbin));
//Data->plotOn(varFrameFit, DataError(RooAbsData::SumW2), MarkerSize(1.0));
  Data->plotOn(varFrameFit, DataError(RooAbsData::Poisson), MarkerSize(1.0));
//Data->statOn(varFrameFit, Layout(0.68,0.99,0.95), Format("N",4));
  sumpdf.plotOn(varFrameFit, LineWidth(2), LineColor(2));
//sumpdf.paramOn(varFrameFit, Layout(0.55, 0.90, 0.90) ); //L,R,U 
//varFrameFit->getAttText()->SetTextSize(0.04);
//varFrameFit->SetFillColor(0);
//varFrameFit->SetFillStyle(0);
  // ------------------------------------------------------------- //
  // Chi2 PrintOut
//cout << "chi^2("<< npar <<") = " << varFrameFit->chiSquare( npar ) << endl ;
  //-------------------------------------------------------------- //
  // Residual
  RooHist* hpull = varFrameFit->pullHist() ;
  RooPlot* framePull = massLc.frame( Title("Pull") ) ;
  hpull->SetFillColor(15);
  hpull->SetLineColor(0);
  framePull->addPlotable( hpull, "B" );
  framePull->GetYaxis()->SetRangeUser( -5.0, 5.0 );

  sumpdf.plotOn(varFrameFit, LineWidth(2), LineColor(2));

  TCanvas* cav1 = new TCanvas("cav1","mc M(D) fit", 600, 500 );
  TPad *pad1 = new TPad("pad1","pad1",0.01,0.20,0.99,0.99);
  TPad *pad2 = new TPad("pad2","pad2",0.01,0.01,0.99,0.20);
  pad1->Draw();
  pad2->Draw();
 
  pad1->cd();
  pad1->SetLeftMargin(0.15);
  //gPad->SetLogy(1); 
  myFormatAxis( varFrameFit, 1 );
  varFrameFit->GetYaxis()->SetRangeUser(0, varFrameFit->GetMaximum()*1.1 );
  varFrameFit->Draw();

  pad2->cd();
  pad2->SetLeftMargin(0.15);
  gPad->SetLogy(0); 
  myFormatAxis( framePull, 2 );
  framePull->Draw();
  PullLine( mFitMin, mFitMax );

  cav1->cd();
//cav1->Print("./eps/MassLc_LcRef_bkgFeed.eps");

}

  
