/**********************************************************
 *                                                        *
 *         BES III Plotstyle: format functions            *
 *                                                        *
 *         August 2009, Niklaus Berger                    *
 *         nberger@ihep.ac.cn                             *
 *                                                        *
 *********************************************************/

#include "bes3plotstyle.h"

#include <TH1.h>
#include <TH1F.h>
#include <TF1.h>
#include <TLatex.h>
#include <TList.h>
#include <TLegend.h>
#include <TCanvas.h>
#include <TAxis.h>
#include <TStyle.h>
#include <TGraph.h>
#include <TMath.h>
#include <iostream>

// enlarge the precision for cout
//cout<< setprecision(8) << xxx <<endl; 

// redraw axias
// cc->RedrawAxis(); //

// set root stat location
// gStyle->SetStatH( 0.12 );
// gStyle->SetStatW( 0.20 );
// gStyle->SetStatX( 0.55 );
// gStyle->SetStatY( 0.80 );

//draw n*times of signal component
//total_PDF.plotOn(frame, Normalization(ntotal->getVal()*n, RooAbsReal::NumEvent), Components(sig_PDF));

// set subregion for fitting
//x.setRange("signal", xSRmin, xSRmax );
//RooFitResult *fiter = sumpdf.fitTo(*Data, Strategy(2), Hesse(kTRUE), Save(kTRUE), Minos(kFALSE), Range("signal") ) ;

//gStyle->SetPadTickX(0); 
//gStyle->SetPadTickY(0);

// avoid WARNING exist histogram or canvas definition.
TString safeName(TString name) {
  TObject *old = gROOT->FindObject(name);
  if(old) delete old;
  return name;
}

void PullLine(double mFitMin, double mFitMax)
{  
  TLine *lineUP = new TLine(mFitMin, 3, mFitMax, 3);
  lineUP->SetLineColor(1);
  lineUP->SetLineStyle(2);
  lineUP->SetLineWidth(1);
  lineUP->Draw();
  TLine *lineDOWN = new TLine(mFitMin, -3, mFitMax, -3);
  lineDOWN->SetLineColor(1);
  lineDOWN->SetLineStyle(2);
  lineDOWN->SetLineWidth(1);
  lineDOWN->Draw();
  TLine *lineZERO = new TLine(mFitMin, 0., mFitMax, 0.);
  lineZERO->SetLineColor(1);
  lineZERO->SetLineStyle(2);
  lineZERO->SetLineWidth(1);
  lineZERO->Draw();
}

// needed in determination of Dalitz boundary
Double_t E2(Double_t x, Double_t m1, Double_t m2)
{
  Double_t e2 = (x-m1*m1+m2*m2)/(2*sqrt(x));
  return e2;
}
 
Double_t E3(Double_t x, Double_t M, Double_t m3)
{
  Double_t e3 = (M*M-x-m3*m3)/(2*sqrt(x));
  return e3;
}
 
Double_t m23Max(Double_t *x, Double_t *par) //par = { M, m1, m2, m3}
{
  Double_t term1 = ( E2(x[0],par[1],par[2]) + E3(x[0],par[0],par[3]) );
  term1 = term1*term1;
 
  Double_t E2sqr= E2(x[0],par[1],par[2])*E2(x[0],par[1],par[2]);
  Double_t E3sqr= E3(x[0],par[0],par[3])*E3(x[0],par[0],par[3]);
 
  Double_t term2 = sqrt(E2sqr-par[2]*par[2])-sqrt( E3sqr - par[3]*par[3] );
  term2 = term2*term2;
  Double_t xx = term1 - term2;
  return xx;
}

Double_t m23Min(Double_t *x, Double_t *par) //par = { M, m1, m2, m3}
{
  Double_t term1 = ( E2(x[0],par[1],par[2]) + E3(x[0],par[0],par[3]) );
  term1 = term1*term1;
 
  Double_t E2sqr= E2(x[0],par[1],par[2])*E2(x[0],par[1],par[2]);
  Double_t E3sqr= E3(x[0],par[0],par[3])*E3(x[0],par[0],par[3]);
 
  Double_t term2 = sqrt(E2sqr-par[2]*par[2])+sqrt( E3sqr - par[3]*par[3] );
  term2 = term2*term2;
  Double_t xx = term1 - term2;
  return xx;                                                                                               
}
 

// Format for data points
void FormatData(TH1 * datahist){
  datahist->SetMarkerStyle(20);
  datahist->SetMarkerSize(1);
  datahist->SetLineWidth(2);

  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
}

// Format for graph data points
void FormatData(TGraph * datahist){
  datahist->SetMarkerStyle(20);
  datahist->SetMarkerSize(1);
  datahist->SetLineWidth(2);
}

void FormatAxis(TAxis * axis){
  axis->SetLabelFont(42);
  axis->SetLabelSize(0.05);
  axis->SetLabelOffset(0.015);
  axis->SetNdivisions(510);
  axis->SetTitleFont(42);
  axis->SetTitleColor(1);
  axis->SetTitleSize(0.065);
  axis->SetTitleOffset(1.0);
  axis->CenterTitle();
/*
  axis->SetTimeDisplay(1);
  axis->SetTimeFormat("#splitline{%m/%d/}{%H:%M:%S}");
*/
}

void myFormatAxis(THStack * hist, const char * xname, const char * yname )
{                                   
  hist->Draw();                     
  FormatAxis(hist->GetXaxis());     
  FormatAxis(hist->GetYaxis());     
  hist->GetXaxis()->SetNdivisions(505); 
  hist->GetXaxis()->SetTitle(xname); 
  hist->GetYaxis()->SetTitle(yname); 
}

void NewText( char * text, int alertFlag=0 ) {

 
  TPaveText * m_text1 = new TPaveText(  0 , 40 , 700 , 60 , "NB");                         
  m_text1->SetFillColorAlpha(kWhite, 0);
  m_text1->SetBorderSize(0);
  TText* tt2 = m_text1->AddText(text);
//  TString Par1V = Form("Ratio = %.1f %%", exRatio * 100.0);                             
//  m_text1->AddText(Par1V);
  if( alertFlag ) {
    TText* tt1 = m_text1->AddText("Alert");
    tt1->SetTextColor(kRed);
    tt2->SetTextColor(kRed);
  }
  m_text1->Draw();
}

void NameAxes(RooPlot* datahist, const char * xname, const char * yname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
} 

void NameAxes(TH1 * datahist, const char * xname, const char * yname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
}

void NameAxes(TGraphErrors * datahist, const char * xname, const char * yname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
}

void NameAxes2D(TH2 * datahist, const char * xname, const char * yname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
  FormatAxis(datahist->GetZaxis());
  datahist->GetZaxis()->SetTitleSize(0.065);
  datahist->GetZaxis()->SetLabelSize(0.05);
}

void NameAxes2D(TH2 * datahist, const char * xname, const char * yname, const char *zname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
  if(zname)
    datahist->GetZaxis()->SetTitle(zname);
  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
  FormatAxis(datahist->GetZaxis());
  datahist->GetZaxis()->SetTitleSize(0.065);
  datahist->GetZaxis()->SetLabelSize(0.05);
}

void NameAxes2D(TF2 * datahist, const char * xname, const char * yname, const char *zname){
  if(xname)
    datahist->GetXaxis()->SetTitle(xname);
  if(yname)
    datahist->GetYaxis()->SetTitle(yname);
  if(zname)
    datahist->GetZaxis()->SetTitle(zname);
  FormatAxis(datahist->GetXaxis());
  FormatAxis(datahist->GetYaxis());
  FormatAxis(datahist->GetZaxis());
  datahist->GetZaxis()->SetTitleSize(0.065);
  datahist->GetZaxis()->SetLabelSize(0.05);
} 

// Format for main MC (red line)
void FormatMC1(TH1 * mc1hist){
  mc1hist->SetLineColor(2);
  mc1hist->SetLineWidth(2);
  FormatAxis( mc1hist->GetXaxis() );
  FormatAxis( mc1hist->GetYaxis() );
}

// Graph Format for main MC (red line)
void FormatMC1(TGraph * mc1hist){
  mc1hist->SetLineColor(2);
  mc1hist->SetLineWidth(2);
}


// Format for second MC or background
// (Blue shaded area)
void FormatMC2(TH1 * mc2hist){
  mc2hist->SetLineColor(4);
  mc2hist->SetFillColor(4);
  mc2hist->SetLineWidth(2);
  mc2hist->SetFillStyle(3001);
}

// Graph Format for second MC or background
// (Blue line)
void FormatMC2(TGraph * mc2hist){
  mc2hist->SetLineColor(4);
  mc2hist->SetLineWidth(2);
}

void FormatMC3(TH1 * mc3hist){
  mc3hist->SetLineColor(6);
  mc3hist->SetLineWidth(2);
  mc3hist->SetLineStyle(2);
  mc3hist->SetFillStyle(0);
}
// Graph Format for third MC or background
// (Blue line)
void FormatMC3(TGraph * mc3hist){
  mc3hist->SetLineColor(6);
  mc3hist->SetLineWidth(2);
  mc3hist->SetLineStyle(2);
}

// Write "BESIII" in the upper right corner
void WriteBes3(){
  TLatex * bes3 = new TLatex(0.94,0.94, "BESIII");
  bes3->SetNDC();
  bes3->SetTextFont(72);
  bes3->SetTextSize(0.1);
  bes3->SetTextAlign(33);
//  bes3->Draw();
}

// Write "BESIII" in the upper right corner
void WriteBelle(){
  TLatex * bes3 = new TLatex(0.94,0.94, "BELLE");
  bes3->SetNDC();
  bes3->SetTextFont(72);
  bes3->SetTextSize(0.1);
  bes3->SetTextAlign(33);
  bes3->Draw();
}



// Write "Preliminary" below BESIII -
// to be used together with WriteBes3()
void WritePreliminary(){
  TLatex * prelim = new TLatex(0.94,0.86, "Preliminary");
  prelim->SetNDC();
  prelim->SetTextFont(62);
  prelim->SetTextSize(0.055);
  prelim->SetTextAlign(33);
//  prelim->Draw();
}

void FormatArrow(TArrow *arr){
  arr->SetLineColor(4);
  arr->SetLineWidth(2);
}

// Make a legend; 
void MakeLegend0(TH1 * mc1hist, // Histogram with first MC
                char * mc1name, // Description of first MC
                TH1 * mc2hist, // Histogram with 2nd MC/BG
                char * mc2name, // Description of second MC/BG
                double xlow,      // Left edge of legend 
                                  //(fraction of canavas width)
                double ylow,       // Bottom edge of legend
                                  //(fraction of canavas height)
                double xhi,       // Right edge of legend 
                                  //(fraction of canavas width)
                double yhi){       // Top edge of legend
                                  //(fraction of canavas height)

  TLegend * leg = new TLegend(xlow, ylow, xhi, yhi);
  if(mc1hist && mc1name)
    leg->AddEntry(mc1hist, mc1name, "L");
  if(mc2hist && mc2name)
    leg->AddEntry(mc2hist, mc2name, "L");

  leg->SetFillColor(10);
  leg->SetTextFont(42);
  leg->Draw();

}
// position will have to change depending on the data shape
void MakeLegend(TH1 * datahist,   // Histogram with data
		char * dataname,  // Description of data
		TH1 * mc1hist, // Histogram with first MC
		char * mc1name, // Description of first MC
		TH1 * mc2hist, // Histogram with 2nd MC/BG
		char * mc2name, // Description of second MC/BG
		double xlow,      // Left edge of legend 
		                  //(fraction of canavas width)
		double ylow,       // Bottom edge of legend
		                  //(fraction of canavas height)
		double xhi,       // Right edge of legend 
		                  //(fraction of canavas width)
		double yhi){       // Top edge of legend
		                  //(fraction of canavas height)

  TLegend * leg = new TLegend(xlow, ylow, xhi, yhi);
  if(datahist && dataname)
    leg->AddEntry(datahist, dataname, "LEP");
  if(mc1hist && mc1name)
    leg->AddEntry(mc1hist, mc1name, "L");
  if(mc2hist && mc2name)
    leg->AddEntry(mc2hist, mc2name, "LF");
  
  leg->SetFillColor(10);
  leg->SetTextFont(42);
  leg->Draw();

}


// Make a legend; 
// position will have to change depending on the data shape
void MakeLegend(TGraph * datahist,   // Graph with data
		char * dataname,  // Description of data
		TGraph * mc1hist, // Graph with first MC
		char * mc1name, // Description of first MC
		TGraph * mc2hist, // Graph with 2nd MC/BG
		char * mc2name, // Description of second MC/BG
		TGraph * mc3hist, // Graph with 3rd MC/BG
		char * mc3name, // Description of third MC/BG

		double xlow,      // Left edge of legend 
		                  //(fraction of canavas width)
		double ylow,       // Bottom edge of legend
		                  //(fraction of canavas height)
		double xhi,       // Right edge of legend 
		                  //(fraction of canavas width)
		double yhi){       // Top edge of legend
		                  //(fraction of canavas height)

  TLegend * leg = new TLegend(xlow, ylow, xhi, yhi);
  if(datahist && dataname)
    leg->AddEntry(datahist, dataname, "LEP");
  if(mc1hist && mc1name)
    leg->AddEntry(mc1hist, mc1name, "L");
  if(mc2hist && mc2name)
    leg->AddEntry(mc2hist, mc2name, "L");
  if(mc3hist && mc3name)
    leg->AddEntry(mc3hist, mc3name, "L");
  
  leg->SetFillColor(10);
  leg->SetTextFont(42);
  leg->Draw();

}



// Make a legend (version for fit functions
// position will have to change depending on the data shape
void MakeLegend(TH1 * datahist,   // Histogram with data
		char * dataname,  // Description of data
		char ** functionnames, // list of function names
		double xlow,      // Left edge of legend 
		                  //(fraction of canavas width)
		double ylow,       // Bottom edge of legend
		                  //(fraction of canavas height)
		double xhi,       // Right edge of legend 
		                  //(fraction of canavas width)
		double yhi){       // Top edge of legend
		                  //(fraction of canavas height)

  TLegend * leg = new TLegend(xlow, ylow, xhi, yhi);
  if(datahist && dataname)
    leg->AddEntry(datahist, dataname, "LEP");

  TList* list = datahist->GetListOfFunctions();
  unsigned int nfun = list->GetEntries();

  for(unsigned int i =0;  i < nfun; i++){
    TF1* f1 = (TF1*)(list->At(i));
    leg->AddEntry(f1, functionnames[i], "L");
  }
  leg->SetFillColor(10);
  leg->SetTextFont(42);
  leg->Draw();

}

// Set the general style options
void SetStyle(){
  gROOT->Reset();
  gROOT->SetStyle("Plain");
  // No Canvas Border; White BG
  gStyle->SetCanvasBorderMode(0);
  gStyle->SetCanvasBorderSize(0);
  gStyle->SetCanvasColor(10);
  // frame
  gStyle->SetFrameBorderMode(0); 
  gStyle->SetFrameFillColor(0);
  gStyle->SetFrameFillStyle(1001);

  gStyle->SetPaperSize(20,26);

  // Format for axes
  gStyle->SetLabelFont(42,"xyz");
  gStyle->SetTitleFont(42,"xyz");
  gStyle->SetLabelSize(0.05,"xyz");
  gStyle->SetTitleSize(0.065,"xyz");

  //set title offsets (for axis label) 
  gStyle->SetTitleXOffset(1.0); 
  gStyle->SetTitleYOffset(1.0);

  gStyle->SetLabelOffset(0.015,"xyz");
  gStyle->SetTitleOffset(1.1,"xyz");
  gStyle->SetNdivisions(510,"xyz");
  gStyle->SetTitleColor(1,"xyz");

  gStyle->SetTickLength(0.03,"x");
  gStyle->SetTickLength(0.02,"y");

  // No pad borders
  gStyle->SetPadBorderMode(0);
  gStyle->SetPadBorderSize(0);
  // White BG
  gStyle->SetPadColor(10);
  // Margins for labels etc.
  gStyle->SetPadLeftMargin(0.16);
  gStyle->SetPadBottomMargin(0.16);
  gStyle->SetPadRightMargin(0.05);
  gStyle->SetPadTopMargin(0.05);

  // No error bars in x direction
  gStyle->SetErrorX(0);
  // get rid of error bar caps
  gStyle->SetEndErrorSize(0.);

  // put tick marks on top and RHS of plots 
  gStyle->SetPadTickX(1);
  gStyle->SetPadTickY(1);

  // Format legend
  gStyle->SetLegendBorderSize(0);
  gStyle->SetFrameLineWidth(2); 
}

// Style options for "final" plots
// (no stat/fit box)
void SetPrelimStyle(){
  gStyle->SetOptDate(0);
  gStyle->SetOptStat(0);
  gStyle->SetOptFit(0);
  gStyle->SetOptTitle(0);
}

// Style options for internal meetings
// (stat/fit box)
void SetMeetingStyle(){
  gStyle->SetOptDate(0);
  gStyle->SetOptTitle(0);
//  gStyle->SetOptStat(1111);
  gStyle->SetOptStat("e"); //the number of entries 
//  gStyle->SetOptStat("i"); //the integral of bins
  gStyle->SetStatBorderSize(1);
  gStyle->SetStatColor(0);
  gStyle->SetStatFont(42);
  gStyle->SetStatFontSize(0.03);
  gStyle->SetOptFit(1111);
  
}


// Plot a data MC plot
void PlotDataMC(char * filename,  // Name for the output files, 
		                  // without extension 
		TH1 * datahist,   // Histogram with data
		char * dataname,  // Description of data
		TH1 * mc1hist, // Histogram with first MC
		char * mc1name, // Description of first MC
		TH1 * mc2hist, // Histogram with 2nd MC/BG
		char * mc2name, // Description of second MC/BG
		bool prelim, // Preliminary plot
		double xlow, // Left edge of legend 
		                    //(fraction of canavas width)
		double ylow,  // Bottom edge of legend
		                    //(fraction of canavas height)
		double xhi,  // Right edge of legend 
		                    //(fraction of canavas width)
		double yhi){  // Top edge of legend
		                    //(fraction of canavas height)
      
  SetStyle();
  if(prelim)
    SetPrelimStyle();
  else
    SetMeetingStyle();

//  TCanvas * c1 = new TCanvas("bes3plots","BESIII Plots", 800,600);

  FormatData(datahist);
  if(mc1hist)
    FormatMC1(mc1hist);
  if(mc2hist)
    FormatMC2(mc2hist);
///*add by llk
//  double nevents = datahist->GetMaximum();
//  datahist->GetYaxis()->SetRangeUser(0., nevents*1.2);
//*/
  datahist->Draw("axis");
  if(mc2hist)
    mc2hist->Draw("histsame");
  if(mc1hist)
    mc1hist->Draw("histsame");
  datahist->Draw("Esame");
  datahist->Draw("axissame");
  if(prelim){
    WriteBes3();
    WritePreliminary();
  }

 MakeLegend(datahist, dataname,
	    mc1hist,  mc1name,
	    mc2hist,  mc2name);


/*
 char filenameall[256];
 sprintf(filenameall,"%s.eps", filename);
 c1->SaveAs(filenameall);
 sprintf(filenameall,"%s.png", filename);
 c1->SaveAs(filenameall);
*/
}

// Plot a data MC plot
void PlotDataMC2(char * filename,  // Name for the output files, 
                                  // without extension 
                TH1 * datahist,   // Histogram with data
                char * dataname,  // Description of data
                TH1 * mc1hist, // Histogram with first MC
                char * mc1name, // Description of first MC
                TH1 * mc2hist, // Histogram with 2nd MC/BG
                char * mc2name, // Description of second MC/BG
                bool prelim, // Preliminary plot
                double xlow, // Left edge of legend 
                                    //(fraction of canavas width)
                double ylow,  // Bottom edge of legend
                                    //(fraction of canavas height)
                double xhi,  // Right edge of legend 
                                    //(fraction of canavas width)
                double yhi){  // Top edge of legend
                                    //(fraction of canavas height)

  SetStyle();
  if(prelim)
    SetPrelimStyle();
  else
    SetMeetingStyle();

  TCanvas * c1 = new TCanvas("belleplots","BELLE Plots", 800,600);
// color alert 
// cav2->Pad()->SetFillColor( kYellow ); 

//  TText* tbad = m_text1->AddText(">1% bad, report to TOP experts!");
//  tbad->SetTextColor(kRed);

  FormatData(datahist);
  if(mc1hist)
    FormatMC1(mc1hist);
  if(mc2hist)
    FormatMC2(mc2hist);


  datahist->Draw("axis");
  if(mc2hist)
    mc2hist->Draw("histsame");
  if(mc1hist)
    mc1hist->Draw("histsame");
  datahist->Draw("Esame");
  datahist->Draw("axissame");
  if(prelim){
    WriteBelle();
    WritePreliminary();
  }
}










// Plot data with one or more (fit) functions
// Functions should be part of the data histograms list of functions
// (i.e. perform fits with the "+" option or add other functions via
// datahist->GetListOfFunctions->Add(TF1 * function))
// functionnames should have at least as many elements as the function
// list
void PlotDataFit(char * filename,  // Name for the output files, 
		                  // without extension 
		TH1F * datahist,   // Histogram with data
		char * dataname,  // Description of data
		char ** functionnames,// Names of associated functions
		bool prelim, // Preliminary plot
		double xlow, // Left edge of legend 
		                    //(fraction of canavas width)
		double ylow,  // Bottom edge of legend
		                    //(fraction of canavas height)
		double xhi,  // Right edge of legend 
		                    //(fraction of canavas width)
		double yhi){  // Top edge of legend
		                    //(fraction of canavas height)


 SetStyle();

 if(prelim)
   SetPrelimStyle();
 else
   SetMeetingStyle();

  TCanvas * c1 = new TCanvas("bes3plots","BESIII Plots", 800,600);

// gPad->SetLogy();
  FormatData(datahist);
  Float_t rightmax = 1.1 * datahist->GetMaximum();
  datahist->SetMaximum(rightmax);

  int linestyles[] = {1,2,3,7,9,10};
  //int linecolors[]   = {2,4,kGreen+2,kOrange+7,kMagenta,2};
  int linecolors[]   = {2,4,6, 9,8,2};

 TList* list = datahist->GetListOfFunctions();
  TH1F * datacopy = new TH1F(*datahist); 
  datacopy->Draw("axis");


  unsigned int nfun = list->GetEntries();
  
  if(nfun > 6){
    std::cout << "ERROR: More than six associated functions not forseen" << std::endl;
    return;
  }


  for(unsigned int i =0;  i < nfun; i++){
    TF1* f1 = (TF1*)(list->At(i));
    f1->SetLineColor(linecolors[i]);
    f1->SetLineStyle(linestyles[i]);
    f1->Draw("same");
  }

//  MakeLegend(datahist, dataname, functionnames,xlow, ylow, xhi, yhi);

  datacopy->Draw("Esame");
  datacopy->Draw("axissame");

  if(prelim){
    WriteBes3();
    WritePreliminary();
  }

//char filenameall[256];
//sprintf(filenameall,"%s.eps", filename);
//c1->SaveAs(filenameall);
//  sprintf(filenameall,"%s.png", filename);
//  c1->SaveAs(filenameall);


}


// Scatter plot
void PlotScatter(char * filename,  // Name for the output files, 
		                   // without extension 
		 TH1 * datahist,   // Histogram with data
		 bool prelim       // preliminary plot
		 ){
		                  
      
  SetStyle();
  if(prelim)
    SetPrelimStyle();
  else
    SetMeetingStyle();

  TCanvas * c1 = new TCanvas("bes3plots","BESIII Plots", 800,600);

  FormatData(datahist);
  
  if(datahist->Integral() > 5000)
    datahist->SetMarkerStyle(20);
  else if(datahist->Integral() > 500)
    datahist->SetMarkerSize(0.5);
  
  
  datahist->Draw("");

//  if(prelim){
//    WriteBes3();
//    WritePreliminary();
//  }


// char filenameall[256];
// sprintf(filenameall,"%s.eps", filename);
// c1->SaveAs(filenameall);
// sprintf(filenameall,"%s.png", filename);
// c1->SaveAs(filenameall);
}

// Plot a  MC plot
void PlotMC(char * filename,  // Name for the output files, 
                                  // without extension 
                TH1 * mc1hist, // Histogram with first MC
                char * mc1name, // Description of first MC
                bool prelim, // Preliminary plot
                double xlow, // Left edge of legend 
                                    //(fraction of canavas width)
                double ylow,  // Bottom edge of legend
                                    //(fraction of canavas height)
                double xhi,  // Right edge of legend 
                                    //(fraction of canavas width)
                double yhi){  // Top edge of legend
                                    //(fraction of canavas height)

  SetStyle();
  if(prelim)
    SetPrelimStyle();
  else
    SetMeetingStyle();
    
  TCanvas * c1 = new TCanvas("bes3plots","BESIII Plots", 800,600);
  FormatMC1(mc1hist);
  Float_t rightmax = 1.1 * mc1hist->GetMaximum();
  mc1hist->SetMaximum(rightmax);
  mc1hist->Draw("hist");
  if(prelim){
    WriteBes3();
    WritePreliminary();
  }

}



